summaryrefslogtreecommitdiff
path: root/src/termchar.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/termchar.h')
-rw-r--r--src/termchar.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/termchar.h b/src/termchar.h
index 87072136317..f4b58f105b0 100644
--- a/src/termchar.h
+++ b/src/termchar.h
@@ -58,9 +58,9 @@ struct tty_display_info
int reference_count; /* Number of frames that are on this display. */
- struct device *device; /* Points back to the generic display device
+ struct terminal *terminal; /* Points back to the generic terminal
structure. This is sometimes handy. */
-
+
/* Info on cursor positioning. */
struct cm *Wcm;
@@ -194,7 +194,7 @@ extern struct tty_display_info *tty_list;
#define FRAME_TTY(f) \
((f)->output_method == output_termcap \
- ? (f)->device->display_info.tty \
+ ? (f)->terminal->display_info.tty \
: (abort(), (struct tty_display_info *) 0))
#define CURTTY() FRAME_TTY (SELECTED_FRAME())